Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
& becomes \&).-l/--single-line flag to collapse newlines within field values into a single space.bibfmt directly accepts a list of files. To make it read from stdin, useful for autoformatting, use - as filename.doi2bib ID1 ID2 ID3).. and / in the citekey.